@@ -72,6 +72,7 @@ class FastTable(Widget):
     """
 
     class Routes:
+        SELECTION_CHANGED = "selection_changed_cb"
         ROW_CLICKED = "row_clicked_cb"
         CELL_CLICKED = "cell_clicked_cb"
         UPDATE_DATA = "update_data_cb"
@@ -100,6 +101,29 @@ class FastTable(Widget):
             self.column_name = column_name
             self.column_value = column_value
 
+    class ColumnData:
+        def __init__(self, name, is_widget=False, widget: Widget = None):
+            self.name = name
+            self.is_widget = is_widget
+            self.widget = widget
+
+        @property
+        def widget_html(self):
+            html = self.widget.to_html()
+            html = html.replace(f".{self.widget.widget_id}", "[JSON.parse(cellValue).widget_id]")
+            html = html.replace(
+                f"/{self.widget.widget_id}", "/' + JSON.parse(cellValue).widget_id + '"
+            )
+            if hasattr(self.widget, "_widgets"):
+                for i, widget in enumerate(self.widget._widgets):
+                    html = html.replace(
+                        f".{widget.widget_id}", f"[JSON.parse(cellValue).widgets[{i}]]"
+                    )
+                    html = html.replace(
+                        f"/{widget.widget_id}", f"/' + JSON.parse(cellValue).widgets[{i}] + '"
+                    )
+            return html
+
     def __init__(
         self,
         data: Optional[Union[pd.DataFrame, List]] = None,
@@ -113,23 +137,48 @@ class FastTable(Widget):
         width: Optional[str] = "auto",
         widget_id: Optional[str] = None,
         show_header: bool = True,
+        is_radio: bool = False,
+        is_selectable: bool = False,
+        header_left_content: Optional[Widget] = None,
+        header_right_content: Optional[Widget] = None,
     ):
         self._supported_types = tuple([pd.DataFrame, list, type(None)])
         self._row_click_handled = False
         self._cell_click_handled = False
-        self._columns_first_idx = columns
+        self._selection_changed_handled = False
+        self._columns = columns
+        self._columns_data = []
+        if columns is None:
+            self._columns_first_idx = None
+        else:
+            self._columns_first_idx = []
+            for col in columns:
+                if isinstance(col, str):
+                    self._columns_first_idx.append(col)
+                    self._columns_data.append(self.ColumnData(name=col))
+                elif isinstance(col, tuple):
+                    self._columns_first_idx.append(col[0])
+                    self._columns_data.append(
+                        self.ColumnData(name=col[0], is_widget=True, widget=col[1])
+                    )
+                else:
+                    raise TypeError(f"Column name must be a string or a tuple, got {type(col)}")
+
         self._columns_options = columns_options
         self._sorted_data = None
         self._filtered_data = None
+        self._searched_data = None
         self._active_page = 1
         self._width = width
-        self._selected_row = None
+        self._selected_rows = None
         self._selected_cell = None
-        self._clickable_rows = False
-        self._clickable_cells = False
+        self._is_row_clickable = False
+        self._is_cell_clickable = False
         self._search_str = ""
         self._show_header = show_header
         self._project_meta = self._unpack_project_meta(project_meta)
+        self._header_left_content = header_left_content
+        self._header_right_content = header_right_content
 
         # table_options
         self._page_size = page_size
@@ -137,6 +186,12 @@ class FastTable(Widget):
         self._sort_column_idx = sort_column_idx
         self._sort_order = sort_order
         self._validate_sort_attrs()
+        self._is_radio = is_radio
+        self._is_selectable = is_selectable
+        self._search_function = self._default_search_function
+        self._sort_function = self._default_sort_function
+        self._filter_function = self._default_filter_function
+        self._filter_value = None
 
         # to avoid errors with the duplicated names in columns
         self._multi_idx_columns = None
@@ -154,6 +209,9 @@ class FastTable(Widget):
 
         self._rows_total = len(self._parsed_source_data["data"])
 
+        if self._is_radio and self._rows_total > 0:
+            self._selected_rows = [self._parsed_source_data["data"][0]]
+
         super().__init__(widget_id=widget_id, file_path=__file__)
 
         script_path = "./sly/css/app/widgets/fast_table/script.js"
@@ -163,27 +221,32 @@ class FastTable(Widget):
         server = self._sly_app.get_server()
 
         @server.post(filter_changed_route_path)
-        def _filter_changed():
-            self._active_page = StateJson()[self.widget_id]["page"]
-            self._sort_order = StateJson()[self.widget_id]["sort"]["order"]
-            self._sort_column_idx = StateJson()[self.widget_id]["sort"]["column"]
-            search_value = StateJson()[self.widget_id]["search"]
-            self._filtered_data = self.search(search_value)
-            self._rows_total = len(self._filtered_data)
+        def _filter_changed_handler():
+            self._refresh()
 
-            if self._rows_total > 0 and self._active_page == 0: # if previous filtered data was empty
-                self._active_page = 1
-                StateJson()[self.widget_id]["page"] = self._active_page
+    def _refresh(self):
+        # TODO sort widgets
+        self._active_page = StateJson()[self.widget_id]["page"]
+        self._sort_order = StateJson()[self.widget_id]["sort"]["order"]
+        self._sort_column_idx = StateJson()[self.widget_id]["sort"]["column"]
+        search_value = StateJson()[self.widget_id]["search"]
+        self._filtered_data = self._filter(self._filter_value)
+        self._searched_data = self._search(search_value)
+        self._rows_total = len(self._searched_data)
 
-            self._sorted_data = self._sort_table_data(self._filtered_data)
-            self._sliced_data = self._slice_table_data(
-                self._sorted_data, actual_page=self._active_page
-            )
-            self._parsed_active_data = self._unpack_pandas_table_data(self._sliced_data)
-            DataJson()[self.widget_id]["data"] = self._parsed_active_data["data"]
-            DataJson()[self.widget_id]["total"] = self._rows_total
-            DataJson().send_changes()
-            StateJson().send_changes()
+        if self._rows_total > 0 and self._active_page == 0:  # if previous filtered data was empty
+            self._active_page = 1
+            StateJson()[self.widget_id]["page"] = self._active_page
+
+        self._sorted_data = self._sort_table_data(self._searched_data)
+        self._sliced_data = self._slice_table_data(self._sorted_data, actual_page=self._active_page)
+        self._parsed_active_data = self._unpack_pandas_table_data(self._sliced_data)
+        StateJson().send_changes()
+        DataJson()[self.widget_id]["data"] = self._parsed_active_data["data"]
+        DataJson()[self.widget_id]["total"] = self._rows_total
+        DataJson().send_changes()
+        StateJson()["reactToChanges"] = True
+        StateJson().send_changes()
 
     def get_json_data(self) -> Dict[str, Any]:
         """Returns dictionary with widget data, which defines the appearance and behavior of the widget.
@@ -209,12 +272,14 @@ class FastTable(Widget):
             "columnsOptions": self._columns_options,
             "total": self._rows_total,
             "options": {
-                "isRowClickable": self._clickable_rows,
-                "isCellClickable": self._clickable_cells,
+                "isRowClickable": self._is_row_clickable,
+                "isCellClickable": self._is_cell_clickable,
                 "fixColumns": self._fix_columns,
+                "isRadio": self._is_radio,
             },
             "pageSize": self._page_size,
             "showHeader": self._show_header,
+            "selectionChangedHandled": self._selection_changed_handled,
         }
 
     def get_json_state(self) -> Dict[str, Any]:
@@ -233,7 +298,7 @@ class FastTable(Widget):
         """
         return {
             "search": self._search_str,
-            "selectedRow": self._selected_row,
+            "selectedRows": self._selected_rows,
             "selectedCell": self._selected_cell,
             "page": self._active_page,
             "sort": {
@@ -289,6 +354,35 @@ class FastTable(Widget):
         self._page_size = size
         DataJson()[self.widget_id]["pageSize"] = self._page_size
 
+    def set_sort(
+        self, func: Callable[[pd.DataFrame, int, Optional[Literal["asc", "desc"]]], pd.DataFrame]
+    ) -> None:
+        """Sets custom sort function for the table.
+
+        :param func: Custom sort function
+        :type func: Callable[[pd.DataFrame, int, Optional[Literal["asc", "desc"]]], pd.DataFrame]
+        """
+        self._sort_function = func
+
+    def set_search(self, func: Callable[[pd.DataFrame, str], pd.DataFrame]) -> None:
+        """Sets custom search function for the table.
+
+        :param func: Custom search function
+        :type func: Callable[[pd.DataFrame, str], pd.DataFrame]
+        """
+        self._search_function = func
+
+    def set_filter(self, filter_function: Callable[[pd.DataFrame, Any], pd.DataFrame]) -> None:
+        """Sets a custom filter function for the table.
+        first argument is a DataFrame, second argument is a filter value.
+
+        :param filter_function: Custom filter function
+        :type filter_function: Callable[[pd.DataFrame, Any], pd.DataFrame]
+        """
+        if filter_function is None:
+            filter_function = self._default_filter_function
+        self._filter_function = filter_function
+
     def read_json(self, data: Dict, meta: Dict = None) -> None:
         """Replace table data with options and project meta in the widget
 
@@ -305,6 +399,7 @@ class FastTable(Widget):
         self._source_data = self._prepare_input_data(self._parsed_source_data)
         self._sliced_data = self._slice_table_data(self._source_data)
         self._parsed_active_data = self._unpack_pandas_table_data(self._sliced_data)
+        self._rows_total = len(self._parsed_source_data["data"])
         init_options = DataJson()[self.widget_id]["options"]
         init_options.update(self._table_options)
         sort = init_options.pop("sort", {"column": None, "order": None})
@@ -332,6 +427,7 @@ class FastTable(Widget):
         self._sliced_data = self._slice_table_data(self._sorted_data)
         self._parsed_active_data = self._unpack_pandas_table_data(self._sliced_data)
         self._parsed_source_data = self._unpack_pandas_table_data(self._source_data)
+        self._rows_total = len(self._parsed_source_data["data"])
         DataJson()[self.widget_id]["data"] = self._parsed_active_data["data"]
         DataJson()[self.widget_id]["columns"] = self._parsed_active_data["columns"]
         DataJson()[self.widget_id]["total"] = len(self._source_data)
@@ -381,9 +477,10 @@ class FastTable(Widget):
 
     def clear_selection(self) -> None:
         """Clears the selection of the table."""
-        StateJson()[self.widget_id]["selectedRow"] = None
+        StateJson()[self.widget_id]["selectedRows"] = None
         StateJson()[self.widget_id]["selectedCell"] = None
         StateJson().send_changes()
+        self._maybe_update_selected_row()
 
     def get_selected_row(self) -> ClickedRow:
         """Returns the selected row.
@@ -391,20 +488,56 @@ class FastTable(Widget):
         :return: Selected row
         :rtype: ClickedRow
         """
-        row_data = StateJson()[self.widget_id]["selectedRow"]
-        row_index = row_data["idx"]
-        row = row_data["row"]
+        if self._is_radio or self._is_selectable:
+            selected_rows = StateJson()[self.widget_id]["selectedRows"]
+            if selected_rows is None:
+                return None
+            if len(selected_rows) == 0:
+                return None
+            if len(selected_rows) > 1:
+                raise ValueError(
+                    "Multiple rows selected. Use get_selected_rows() method to get all selected rows."
+                )
+            row = selected_rows[0]
+            row_index = row["idx"]
+            row = row.get("row", row.get("items", None))
+            if row_index is None or row is None:
+                return None
+            return self.ClickedRow(row, row_index)
+        return self.get_clicked_row()
+
+    def get_selected_rows(self) -> List[ClickedRow]:
+        if self._is_radio or self._is_selectable:
+            selected_rows = StateJson()[self.widget_id]["selectedRows"]
+            rows = []
+            for row in selected_rows:
+                row_index = row["idx"]
+                row_data = row.get("row", row.get("items", None))
+                if row_index is None or row_data is None:
+                    continue
+                rows.append(self.ClickedRow(row_data, row_index))
+            return rows
+        return [self.get_clicked_row()]
+
+    def get_clicked_row(self) -> ClickedRow:
+        clicked_row = StateJson()[self.widget_id]["clickedRow"]
+        if clicked_row is None:
+            return None
+        row_index = clicked_row["idx"]
+        row = clicked_row["row"]
         if row_index is None or row is None:
             return None
         return self.ClickedRow(row, row_index)
 
-    def get_selected_cell(self) -> ClickedCell:
+    def get_clicked_cell(self) -> ClickedCell:
         """Returns the selected cell.
 
         :return: Selected cell
         :rtype: ClickedCell
         """
-        cell_data = StateJson()[self.widget_id]["selectedCell"]
+        cell_data = StateJson()[self.widget_id]["clickedCell"]
+        if cell_data is None:
+            return None
         row_index = cell_data["idx"]
         row = cell_data["row"]
         column_index = cell_data["column"]
@@ -414,6 +547,40 @@ class FastTable(Widget):
             return None
         return self.ClickedCell(row, column_index, row_index, column_name, column_value)
 
+    def get_selected_cell(self) -> ClickedCell:
+        """Alias for get_clicked_cell method.
+        Will be removed in future versions.
+        """
+        return self.get_clicked_cell()
+
+    def _maybe_update_selected_row(self) -> None:
+        if self._is_radio:
+            if self._rows_total != 0:
+                self.select_row(0)
+            else:
+                self._selected_rows = None
+                StateJson()[self.widget_id]["selectedRows"] = None
+                StateJson().send_changes()
+            return
+        if not self._selected_rows:
+            return
+        if self._rows_total == 0:
+            self._selected_rows = None
+            StateJson()[self.widget_id]["selectedRows"] = None
+            StateJson().send_changes()
+            return
+        if self._is_selectable:
+            updated_selected_rows = []
+            for row in self._parsed_source_data["data"]:
+                items = row.get("items", row.get("row", None))
+                if items is not None:
+                    for selected_row in self._selected_rows:
+                        if selected_row.get("row", selected_row.get("items", None)) == items:
+                            updated_selected_rows.append(row)
+            self._selected_rows = updated_selected_rows
+            StateJson()[self.widget_id]["selectedRows"] = self._selected_rows
+            StateJson().send_changes()
+
     def insert_row(self, row: List, index: Optional[int] = -1) -> None:
         """Inserts a row into the table to the specified position.
 
@@ -424,8 +591,7 @@ class FastTable(Widget):
         """
         self._validate_table_sizes(row)
         self._validate_row_values_types(row)
-        table_data = self._parsed_source_data
-        index = len(table_data) if index > len(table_data) or index < 0 else index
+        index = len(self._source_data) if index > len(self._source_data) or index < 0 else index
 
         self._source_data = pd.concat(
             [
@@ -443,6 +609,7 @@ class FastTable(Widget):
         DataJson()[self.widget_id]["data"] = self._parsed_active_data["data"]
         DataJson()[self.widget_id]["total"] = self._rows_total
         DataJson().send_changes()
+        self._maybe_update_selected_row()
 
     def pop_row(self, index: Optional[int] = -1) -> List:
         """Removes a row from the table at the specified position and returns it.
@@ -469,7 +636,7 @@ class FastTable(Widget):
             self._rows_total = len(self._parsed_source_data["data"])
             DataJson()[self.widget_id]["data"] = self._parsed_active_data["data"]
             DataJson()[self.widget_id]["total"] = self._rows_total
-            DataJson().send_changes()
+            self._maybe_update_selected_row()
             return popped_row
 
     def clear(self) -> None:
@@ -482,6 +649,7 @@ class FastTable(Widget):
         DataJson()[self.widget_id]["data"] = []
         DataJson()[self.widget_id]["total"] = 0
         DataJson().send_changes()
+        self._maybe_update_selected_row()
 
     def row_click(self, func: Callable[[ClickedRow], Any]) -> Callable[[], None]:
         """Decorator for function that handles row click event.
@@ -495,8 +663,8 @@ class FastTable(Widget):
         server = self._sly_app.get_server()
 
         self._row_click_handled = True
-        self._clickable_rows = True
-        DataJson()[self.widget_id]["options"]["isRowClickable"] = self._clickable_rows
+        self._is_row_clickable = True
+        DataJson()[self.widget_id]["options"]["isRowClickable"] = self._is_row_clickable
         DataJson().send_changes()
 
         if self._cell_click_handled is True:
@@ -528,8 +696,8 @@ class FastTable(Widget):
         server = self._sly_app.get_server()
 
         self._cell_click_handled = True
-        self._clickable_cells = True
-        DataJson()[self.widget_id]["options"]["isCellClickable"] = self._clickable_cells
+        self._is_cell_clickable = True
+        DataJson()[self.widget_id]["options"]["isCellClickable"] = self._is_cell_clickable
         DataJson().send_changes()
 
         if self._row_click_handled is True:
@@ -549,7 +717,40 @@ class FastTable(Widget):
 
         return _click
 
-    def search(self, search_value: str) -> pd.DataFrame:
+    def _default_filter_function(self, data: pd.DataFrame, filter_value: Any) -> pd.DataFrame:
+        return data
+
+    def _filter_table_data(self, data: pd.DataFrame) -> pd.DataFrame:
+        """Filter source data using a self._filter_function as filter function.
+        To apply a custom filter function, use the set_filter method.
+
+        :return: Filtered data
+        :rtype: pd.DataFrame
+        """
+        filtered_data = self._filter_function(data, self._filter_value)
+        return filtered_data
+
+    def _filter(self, filter_value: Any) -> pd.DataFrame:
+        filtered_data = self._source_data.copy()
+        if filter_value is None:
+            return filtered_data
+        if self._filter_value != filter_value:
+            self._active_page = 1
+            StateJson()[self.widget_id]["page"] = self._active_page
+            StateJson().send_changes()
+        self._filter_value = filter_value
+        filtered_data = self._filter_table_data(filtered_data)
+        return filtered_data
+
+    def filter(self, filter_value) -> None:
+        self._filter_value = filter_value
+        self._refresh()
+
+    def _default_search_function(self, data: pd.DataFrame, search_value: str) -> pd.DataFrame:
+        data = data[data.applymap(lambda x: search_value in str(x)).any(axis=1)]
+        return data
+
+    def _search(self, search_value: str) -> pd.DataFrame:
         """Search source data for search value.
 
         :param search_value: Search value
@@ -557,20 +758,41 @@ class FastTable(Widget):
         :return: Filtered data
         :rtype: pd.DataFrame
         """
-        filtered_data = self._source_data.copy()
+        filtered_data = self._filtered_data.copy()
         if search_value == "":
             return filtered_data
-        else:
-            if self._search_str != search_value:
-                self._active_page = 1
-                StateJson()[self.widget_id]["page"] = self._active_page
-                StateJson().send_changes()
-            filtered_data = filtered_data[
-                filtered_data.applymap(lambda x: search_value in str(x)).any(axis=1)
-            ]
-            self._search_str = search_value
+        if self._search_str != search_value:
+            self._active_page = 1
+            StateJson()[self.widget_id]["page"] = self._active_page
+            StateJson().send_changes()
+        filtered_data = self._search_function(filtered_data, search_value)
+        self._search_str = search_value
         return filtered_data
 
+    def search(self, search_value: str) -> None:
+        StateJson()[self.widget_id]["search"] = search_value
+        StateJson().send_changes()
+        self._refresh()
+
+    def _default_sort_function(
+        self,
+        data: pd.DataFrame,
+        column_idx: Optional[int],
+        order: Optional[Literal["asc", "desc"]],
+    ) -> pd.DataFrame:
+        if order == "asc":
+            ascending = True
+        else:
+            ascending = False
+        try:
+            data = data.sort_values(by=data.columns[column_idx], ascending=ascending)
+        except IndexError as e:
+            e.args = (
+                f"Sorting by column idx = {column_idx} is not possible, your table has only {len(data.columns)} columns with idx from 0 to {len(data.columns) - 1}",
+            )
+            raise e
+        return data
+
     def sort(
         self, column_idx: Optional[int] = None, order: Optional[Literal["asc", "desc"]] = None
     ) -> None:
@@ -588,13 +810,15 @@ class FastTable(Widget):
             StateJson()[self.widget_id]["sort"]["column"] = self._sort_column_idx
         if self._sort_order is not None:
             StateJson()[self.widget_id]["sort"]["order"] = self._sort_order
-        self._filtered_data = self.search(self._search_str)
-        self._rows_total = len(self._filtered_data)
-        self._sorted_data = self._sort_table_data(self._filtered_data)
+        self._filtered_data = self._filter(self._filter_value)
+        self._searched_data = self._search(self._search_str)
+        self._rows_total = len(self._searched_data)
+        self._sorted_data = self._sort_table_data(self._searched_data)
         self._sliced_data = self._slice_table_data(self._sorted_data, actual_page=self._active_page)
         self._parsed_active_data = self._unpack_pandas_table_data(self._sliced_data)
         DataJson()[self.widget_id]["data"] = self._parsed_active_data["data"]
         DataJson()[self.widget_id]["total"] = self._rows_total
+        self._maybe_update_selected_row()
         StateJson().send_changes()
 
     def _prepare_json_data(self, data: dict, key: str):
@@ -746,28 +970,29 @@ class FastTable(Widget):
             data = data.iloc[start_idx:end_idx]
         return data
 
-    def _sort_table_data(self, input_data: pd.DataFrame) -> pd.DataFrame:
+    def _sort_table_data(
+        self,
+        input_data: pd.DataFrame,
+        column_index: Optional[int] = None,
+        sort_order: Optional[Literal["asc", "desc"]] = None,
+    ) -> pd.DataFrame:
         """
         Apply sorting to received data
 
         """
-        if self._sort_order is None or self._sort_column_idx is None:
+        if column_index is None:
+            column_index = self._sort_column_idx
+        if sort_order is None:
+            sort_order = self._sort_order
+
+        if sort_order is None or column_index is None:
             return input_data  # unsorted
 
-        if input_data is not None:
-            if self._sort_order == "asc":
-                ascending = True
-            else:
-                ascending = False
-            data: pd.DataFrame = copy.deepcopy(input_data)
-            try:
-                data = data.sort_values(by=data.columns[self._sort_column_idx], ascending=ascending)
-            except IndexError as e:
-                e.args = (
-                    f"Sorting by column idx = {self._sort_column_idx} is not possible, your table has only {len(data.columns)} columns with idx from 0 to {len(data.columns) - 1}",
-                )
-                raise e
+        data = copy.deepcopy(input_data)
+        if input_data is None:
+            return data
 
+        data = self._sort_function(data=input_data, column_idx=column_index, order=sort_order)
         return data
 
     def _unpack_project_meta(self, project_meta: Union[ProjectMeta, dict]) -> dict:
@@ -857,13 +1082,16 @@ class FastTable(Widget):
         self._sort_column_idx = StateJson()[self.widget_id]["sort"]["column"]
         self._sort_order = StateJson()[self.widget_id]["sort"]["order"]
         self._validate_sort_attrs()
-        self._filtered_data = self.search(self._search_str)
-        self._rows_total = len(self._filtered_data)
-        self._sorted_data = self._sort_table_data(self._filtered_data)
+        self._filtered_data = self._filter(self._filter_value)
+        self._searched_data = self._search(self._search_str)
+        self._rows_total = len(self._searched_data)
+        self._sorted_data = self._sort_table_data(self._searched_data)
 
         increment = 0 if self._rows_total % self._page_size == 0 else 1
         max_page = self._rows_total // self._page_size + increment
-        if self._active_page > max_page: # active page is out of range (in case of the filtered data)
+        if (
+            self._active_page > max_page
+        ):  # active page is out of range (in case of the filtered data)
             self._active_page = max_page
             StateJson()[self.widget_id]["page"] = self._active_page
 
@@ -873,3 +1101,103 @@ class FastTable(Widget):
         DataJson()[self.widget_id]["total"] = self._rows_total
         DataJson().send_changes()
         StateJson().send_changes()
+
+    def selection_changed(self, func):
+        """Decorator for function that handles selection change event.
+
+        :param func: Function that handles selection change event
+        :type func: Callable[[], Any]
+        :return: Decorated function
+        :rtype: Callable[[], None]
+        """
+        selection_changed_route_path = self.get_route_path(FastTable.Routes.SELECTION_CHANGED)
+        server = self._sly_app.get_server()
+
+        @server.post(selection_changed_route_path)
+        def _selection_changed():
+            selected_row = self.get_selected_row()
+            func(selected_row)
+
+        self._selection_changed_handled = True
+        DataJson()[self.widget_id]["selectionChangedHandled"] = True
+        DataJson().send_changes()
+        return _selection_changed
+
+    def select_row(self, idx: int):
+        if not self._is_selectable and not self._is_radio:
+            raise ValueError(
+                "Table is not selectable. Set 'is_selectable' or 'is_radio' to True to use this method."
+            )
+        if idx < 0 or idx >= len(self._parsed_source_data["data"]):
+            raise IndexError(
+                f"Row index {idx} is out of range. Valid range is 0 to {len(self._parsed_source_data['data']) - 1}."
+            )
+        selected_row = self._parsed_source_data["data"][idx]
+        self._selected_rows = [
+            {"idx": idx, "row": selected_row.get("items", selected_row.get("row", None))}
+        ]
+        StateJson()[self.widget_id]["selectedRows"] = self._selected_rows
+        page = idx // self._page_size + 1
+        if self._active_page != page:
+            self._active_page = page
+            StateJson()[self.widget_id]["page"] = self._active_page
+        self._refresh()
+
+    def select_rows(self, idxs: List[int]):
+        if not self._is_selectable:
+            raise ValueError(
+                "Table is not selectable. Set 'is_selectable' to True to use this method."
+            )
+        selected_rows = [
+            self._parsed_source_data["data"][idx]
+            for idx in idxs
+            if 0 <= idx < len(self._parsed_source_data["data"])
+        ]
+        self._selected_rows = [
+            {"idx": row["idx"], "row": row.get("items", row.get("row", None))}
+            for row in selected_rows
+        ]
+        StateJson()[self.widget_id]["selectedRows"] = self._selected_rows
+        StateJson().send_changes()
+
+    def select_row_by_value(self, column, value: Any):
+        """Selects a row by value in a specific column.
+
+        :param column: Column name to filter by
+        :type column: str
+        :param value: Value to select row by
+        :type value: Any
+        """
+        if not self._is_selectable and not self._is_radio:
+            raise ValueError(
+                "Table is not selectable. Set 'is_selectable' to True to use this method."
+            )
+        if column not in self._columns_first_idx:
+            raise ValueError(f"Column '{column}' does not exist in the table.")
+
+        idx = self._source_data[self._source_data[column] == value].index.tolist()
+        if not idx:
+            raise ValueError(f"No rows found with {column} = {value}.")
+        if len(idx) > 1:
+            raise ValueError(
+                f"Multiple rows found with {column} = {value}. Please use select_rows_by_value method."
+            )
+        self.select_row(idx[0])
+
+    def select_rows_by_value(self, column, values: List):
+        """Selects rows by value in a specific column.
+
+        :param column: Column name to filter by
+        :type column: str
+        :param values: List of values to select rows by
+        :type values: List
+        """
+        if not self._is_selectable:
+            raise ValueError(
+                "Table is not selectable. Set 'is_selectable' to True to use this method."
+            )
+        if column not in self._columns_first_idx:
+            raise ValueError(f"Column '{column}' does not exist in the table.")
+
+        idxs = self._source_data[self._source_data[column].isin(values)].index.tolist()
+        self.select_rows(idxs)
